@@ -356,7 +356,7 @@ class FlourishInterventionFilterWidget(InterventionFilterWidget):
 class InterventionStartupView(BrowserView):
     """Dashboard view containing the user's intreventions."""
 
-    title = _("Intervention Dashboard")
+    title = _("Intervention")
     student_title = _("Search Students")
     inbox_title = _("Inbox")
 
@@ -396,9 +396,9 @@ class FlourishInterventionStartupLinks(flourish.page.RefineLinksViewlet):
 
 
 class InterventionStudentsView(BrowserView):
-    """View to search for the user's student intreventions."""
+    """View to search for the user's student interventions."""
 
-    title = _("Search Student Interventions")
+    title = _("Search Students")
     student_title = _("Students")
 
     def __call__(self):
@@ -641,6 +641,7 @@ class FlourishInterventionStudentView(EmailMixin, flourish.page.Page):
                 'creation_date': v.created,
                 'url': absoluteURL(v, self.request),
                 'from': ', '.join(intervention.contactsName(v.sender)),
+                'subject': v.subject,
                 'sent': v.created.strftime('%x'),
                 })
         return sorted(messages, key=lambda m: m['creation_date'], reverse=True)
@@ -825,11 +826,10 @@ class SectionInterventionsView(object):
     def __init__(self, context, request):
         self.context = context
         self.request = request
-        self.section = '%s - %s' % (', '.join([course.title for course in
+        self.heading = '%s - %s %s' % (', '.join([course.title for course in
                                                self.context.courses]),
-                                    self.context.title)
-        self.heading = _("${section}'s Student Interventions",
-                         mapping={'section': self.section})
+                                       self.context.title,
+                                       _("Interventions"))
         self.schoolyear = interfaces.IInterventionSchoolYear(
             ISchoolYear(self.context))
         activities = interfaces.IIndependentActivities(self.context, None)
